package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsRecordLube;

/**
 * 润滑记录Mapper接口
 * 
 * @author Open Platform
 * @date 2024-01-12
 */
public interface DmsRecordLubeMapper 
{
    /**
     * 查询润滑记录
     * 
     * @param recordLubeId 润滑记录主键
     * @return 润滑记录
     */
    public DmsRecordLube selectDmsRecordLubeByRecordLubeId(Long recordLubeId);

    /**
     * 查询润滑记录列表
     * 
     * @param dmsRecordLube 润滑记录
     * @return 润滑记录集合
     */
    public List<DmsRecordLube> selectDmsRecordLubeList(DmsRecordLube dmsRecordLube);

    /**
     * 新增润滑记录
     * 
     * @param dmsRecordLube 润滑记录
     * @return 结果
     */
    public int insertDmsRecordLube(DmsRecordLube dmsRecordLube);

    /**
     * 修改润滑记录
     * 
     * @param dmsRecordLube 润滑记录
     * @return 结果
     */
    public int updateDmsRecordLube(DmsRecordLube dmsRecordLube);

    /**
     * 删除润滑记录
     * 
     * @param recordLubeId 润滑记录主键
     * @return 结果
     */
    public int deleteDmsRecordLubeByRecordLubeId(Long recordLubeId);

    /**
     * 批量删除润滑记录
     * 
     * @param recordLubeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsRecordLubeByRecordLubeIds(Long[] recordLubeIds);
}
