package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsRecordLube;
import com.hw.dms.service.IDmsRecordLubeService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 润滑记录Controller
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/dmsRecordLube")
public class DmsRecordLubeController extends BaseController
{
    @Autowired
    private IDmsRecordLubeService dmsRecordLubeService;

    /**
     * 查询润滑记录列表
     */
    @RequiresPermissions("dms:dmsRecordLube:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsRecordLube dmsRecordLube)
    {
        startPage();
        List<DmsRecordLube> list = dmsRecordLubeService.selectDmsRecordLubeList(dmsRecordLube);
        return getDataTable(list);
    }

    /**
     * 导出润滑记录列表
     */
    @RequiresPermissions("dms:dmsRecordLube:export")
    @Log(title = "润滑记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsRecordLube dmsRecordLube)
    {
        List<DmsRecordLube> list = dmsRecordLubeService.selectDmsRecordLubeList(dmsRecordLube);
        ExcelUtil<DmsRecordLube> util = new ExcelUtil<DmsRecordLube>(DmsRecordLube.class);
        util.exportExcel(response, list, "润滑记录数据");
    }

    /**
     * 获取润滑记录详细信息
     */
    @RequiresPermissions("dms:dmsRecordLube:query")
    @GetMapping(value = "/{recordLubeId}")
    public AjaxResult getInfo(@PathVariable("recordLubeId") Long recordLubeId)
    {
        return success(dmsRecordLubeService.selectDmsRecordLubeByRecordLubeId(recordLubeId));
    }

    /**
     * 新增润滑记录
     */
    @RequiresPermissions("dms:dmsRecordLube:add")
    @Log(title = "润滑记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsRecordLube dmsRecordLube)
    {
        return toAjax(dmsRecordLubeService.insertDmsRecordLube(dmsRecordLube));
    }

    /**
     * 修改润滑记录
     */
    @RequiresPermissions("dms:dmsRecordLube:edit")
    @Log(title = "润滑记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsRecordLube dmsRecordLube)
    {
        return toAjax(dmsRecordLubeService.updateDmsRecordLube(dmsRecordLube));
    }

    /**
     * 删除润滑记录
     */
    @RequiresPermissions("dms:dmsRecordLube:remove")
    @Log(title = "润滑记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordLubeIds}")
    public AjaxResult remove(@PathVariable Long[] recordLubeIds)
    {
        return toAjax(dmsRecordLubeService.deleteDmsRecordLubeByRecordLubeIds(recordLubeIds));
    }
}
